Modules
Structs
- Custom
Rng - Custom random number generator struct for backward compatibility
Functions
- fill_
bytes - Fill the buffer with cryptographically secure random bytes from /dev/urandom. If unavailable (e.g. non-Unix sandbox), fall back to a system-time-seeded LCG generator.
- random_
alphanumeric - Generate a random alphanumeric string of the specified length.
- rng