pub fn from_bytes<T: DeserializeOwned>(bytes: &[u8]) -> Result<T, String>Expand description
Decodes a URL-encoded byte array into any type that implements serde::de::DeserializeOwned.
pub fn from_bytes<T: DeserializeOwned>(bytes: &[u8]) -> Result<T, String>Decodes a URL-encoded byte array into any type that implements serde::de::DeserializeOwned.