pub struct Stringable(/* private fields */);Implementations
Sourceimpl Stringable
impl Stringable
pub fn new(val: String) -> Self
Sourcepub fn after(self, search: &str) -> Self
pub fn after(self, search: &str) -> Self
Get the portion of the string after the first occurrence of a given value
Sourcepub fn before(self, search: &str) -> Self
pub fn before(self, search: &str) -> Self
Get the portion of the string before the first occurrence of a given value
Sourcepub fn between(self, from: &str, to: &str) -> Self
pub fn between(self, from: &str, to: &str) -> Self
Get the portion of the string between two given values