pub struct Str;Implementations
Sourceimpl Str
impl Str
Sourcepub fn of(value: &str) -> Stringable
pub fn of(value: &str) -> Stringable
Membuat instance baru stringable yang lancar (Str::of($value))
Sourcepub fn random(length: usize) -> String
pub fn random(length: usize) -> String
Menghasilkan string acak alfabet/angka dengan panjang tertentu (Str::random())
Sourcepub fn after(subject: &str, search: &str) -> String
pub fn after(subject: &str, search: &str) -> String
Get the portion of a string after the first occurrence of a given value
Sourcepub fn before(subject: &str, search: &str) -> String
pub fn before(subject: &str, search: &str) -> String
Get the portion of a string before the first occurrence of a given value
Sourcepub fn between(subject: &str, from: &str, to: &str) -> String
pub fn between(subject: &str, from: &str, to: &str) -> String
Get the portion of a string between two given values
Sourcepub fn contains(haystack: &str, needle: &str) -> bool
pub fn contains(haystack: &str, needle: &str) -> bool
Determine if a string contains another substring
Sourcepub fn starts_with(subject: &str, needle: &str) -> bool
pub fn starts_with(subject: &str, needle: &str) -> bool
Determine if a string starts with a given substring
Sourcepub fn ends_with(subject: &str, needle: &str) -> bool
pub fn ends_with(subject: &str, needle: &str) -> bool
Determine if a string ends with a given substring